@@ -456,12 +456,9 @@ void countdown_home_widget_edit_event (GtkWidget *button, GdkEventButton *event,
 			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 0, title, 1, printDate, 2, compTime, 3, printTime, -1);
 			gtk_list_store_set (GTK_LIST_STORE (self->priv->entries), &iter, 4, tYears, 5, tWeeks, 6, tDays, 7, tHours, 8, tMinutes, -1);
 			
-			if (position == 0) {
+			if (position < total) {
 				gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &pos, NULL, position);
 				gtk_list_store_move_before (self->priv->entries, &iter, &pos);
-			} else if (position < total ) {
-				gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &pos, NULL, position);
-				gtk_list_store_move_after (self->priv->entries, &iter, &pos);
 			} else {
 				gtk_list_store_move_before (self->priv->entries, &iter, NULL);
 			}
@@ -720,145 +717,151 @@ gboolean countdown_home_widget_update_content (CountdownHomeWidget *self)
 	gtk_container_foreach (GTK_CONTAINER (self->priv->contents), (GtkCallback) gtk_widget_destroy, NULL);
 	
 	exists = gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (self->priv->entries), &iter, NULL, self->priv->offset);
-	while (exists) {
-		GtkWidget *countdownButton;
-		gchar *title="", *date="", *time="";
-		gint years=0, weeks=0, days=0;
-		gint hours=0, minutes=0, seconds=0;
-		gint totDays=0;
-		gboolean showYears, showWeeks, showDays;
-		gboolean showHours, showMinutes;
-		gchar *tempContent="";
-		gchar **content = g_new0 (gchar*, 6);
-		gchar *contentLabelText="";
-		gint index=0;
-		gchar *tail="";
-		gboolean firstShown;
-		
-		gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, -1);
+	if (exists) {
+		while (exists) {
+			GtkWidget *countdownButton;
+			gchar *title="", *date="", *time="";
+			gint years=0, weeks=0, days=0;
+			gint hours=0, minutes=0, seconds=0;
+			gint totDays=0;
+			gboolean showYears, showWeeks, showDays;
+			gboolean showHours, showMinutes;
+			gchar *tempContent="";
+			gchar **content = g_new0 (gchar*, 6);
+			gchar *contentLabelText="";
+			gint index=0;
+			gchar *tail="";
+			gboolean firstShown;
+			
+			gtk_tree_model_get (GTK_TREE_MODEL (self->priv->entries), &iter, 0, &title, 1, &date, 2, &time, 4, &showYears, 5, &showWeeks, 6, &showDays, 7, &showHours, 8, &showMinutes, -1);
 
-		seconds = g_ascii_strtoll (time, NULL,  10);
-		
-		g_date_set_parse (endDate, date);
-		if (!g_date_valid (endDate)) {
-			title = g_strconcat (content[index++], "(INCORRECT DATE!)", NULL);
-			totDays = 0;
-		} else {
-			totDays = g_date_days_between (startDate, endDate);
-		}
-		
-		endSec = seconds;
-		seconds = endSec-startSec;
-		
-		if (totDays > 0) {
-			tail = g_strdup_printf ("left");
-			if (seconds < 0) {
-				totDays--;
-				seconds = (60*60*24)+seconds;
-			}
-		} else if (totDays < 0) {
-			tail = g_strdup_printf ("ago");
-			if (seconds > 0) {
-				totDays++;
-				seconds = (60*60*24)-seconds;
-			}
-		} else {
-			if (seconds < 0) {
-				tail = g_strdup_printf ("ago");
+			seconds = g_ascii_strtoll (time, NULL,  10);
+			
+			g_date_set_parse (endDate, date);
+			if (!g_date_valid (endDate)) {
+				title = g_strconcat (content[index++], "(INCORRECT DATE!)", NULL);
+				totDays = 0;
 			} else {
+				totDays = g_date_days_between (startDate, endDate);
+			}
+			
+			endSec = seconds;
+			seconds = endSec-startSec;
+			
+			if (totDays > 0) {
 				tail = g_strdup_printf ("left");
+				if (seconds < 0) {
+					totDays--;
+					seconds = (60*60*24)+seconds;
+				}
+			} else if (totDays < 0) {
+				tail = g_strdup_printf ("ago");
+				if (seconds > 0) {
+					totDays++;
+					seconds = (60*60*24)-seconds;
+				}
+			} else {
+				if (seconds < 0) {
+					tail = g_strdup_printf ("ago");
+				} else {
+					tail = g_strdup_printf ("left");
+				}
 			}
-		}
-		
-		firstShown = FALSE;
+			
+			firstShown = FALSE;
 
-		totDays=ABS(totDays);
-		seconds=ABS(seconds);
-		
-		if (showYears) {
-			years=totDays/365;
-			if ((firstShown)||(years!=0)||((!showWeeks)&&(!showDays)&&(!showHours)&&(!showMinutes))) {
+			totDays=ABS(totDays);
+			seconds=ABS(seconds);
+			
+			if (showYears) {
+				years=totDays/365;
+				if ((firstShown)||(years!=0)||((!showWeeks)&&(!showDays)&&(!showHours)&&(!showMinutes))) {
+					firstShown = TRUE;
+					tempContent = g_strdup_printf ("%d", ABS (years));
+					content[index++] = g_strconcat (tempContent, " years ", NULL);
+					g_free (tempContent);
+				}
+			}
+			if (showWeeks) {
+				weeks = (totDays-(years*365))/7;
+				if ((firstShown)||(weeks!=0)||((!showDays)&&(!showHours)&&(!showMinutes))) {
+					firstShown = TRUE;
+					tempContent = g_strdup_printf ("%d", ABS (weeks));
+					content[index++] = g_strconcat (tempContent, " weeks ", NULL);
+					g_free (tempContent);
+				}
+			}
+			if (showDays) {
+				days = totDays-(weeks*7)-(years*365);
+				if ((firstShown)||(days!=0)||((!showHours)&&(!showMinutes))) {
+					firstShown = TRUE;
+					tempContent = g_strdup_printf ("%d", ABS (days));
+					content[index++] = g_strconcat (tempContent, " days ", NULL);
+					g_free (tempContent);
+				}
+			}
+			if (showHours) {
+				hours = ((totDays-(days+(weeks*7)+(years*365)))*(24))+seconds/(60*60);
+				if ((firstShown)||(hours!=0)||(!showMinutes)) {
+					firstShown = TRUE;
+					tempContent = g_strdup_printf ("%d", ABS (hours));
+					content[index++] = g_strconcat (tempContent, " hours ", NULL);
+					g_free (tempContent);
+				}
+			}
+			if (showMinutes) {
+				minutes=((totDays-(days+(weeks*7)+(years*365)))*(24*60))+((seconds/60)-(hours*60));
 				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", ABS (years));
-				content[index++] = g_strconcat (tempContent, " years ", NULL);
+				tempContent = g_strdup_printf ("%d", ABS (minutes));
+				content[index++] = g_strconcat (tempContent, " mins ", NULL);
 				g_free (tempContent);
 			}
-		}
-		if (showWeeks) {
-			weeks = (totDays-(years*365))/7;
-			if ((firstShown)||(weeks!=0)||((!showDays)&&(!showHours)&&(!showMinutes))) {
-				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", ABS (weeks));
-				content[index++] = g_strconcat (tempContent, " weeks ", NULL);
-				g_free (tempContent);
-			}
-		}
-		if (showDays) {
-			days = totDays-(weeks*7)-(years*365);
-			if ((firstShown)||(days!=0)||((!showHours)&&(!showMinutes))) {
-				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", ABS (days));
-				content[index++] = g_strconcat (tempContent, " days ", NULL);
-				g_free (tempContent);
-			}
-		}
-		if (showHours) {
-			hours = ((totDays-(days+(weeks*7)+(years*365)))*(24))+seconds/(60*60);
-			if ((firstShown)||(hours!=0)||(!showMinutes)) {
-				firstShown = TRUE;
-				tempContent = g_strdup_printf ("%d", ABS (hours));
-				content[index++] = g_strconcat (tempContent, " hours ", NULL);
-				g_free (tempContent);
-			}
-		}
-		if (showMinutes) {
-			minutes=((totDays-(days+(weeks*7)+(years*365)))*(24*60))+((seconds/60)-(hours*60));
-			firstShown = TRUE;
-			tempContent = g_strdup_printf ("%d", ABS (minutes));
-			content[index++] = g_strconcat (tempContent, " mins ", NULL);
-			g_free (tempContent);
-		}
-		content[index] = g_strconcat (tail, NULL);
-		
-		contentLabelText = g_strjoinv (NULL, content);
-		GtkWidget *event = gtk_event_box_new ();
-		gtk_event_box_set_visible_window (GTK_EVENT_BOX (event), FALSE);
-		gtk_container_set_border_width (GTK_CONTAINER (event), 5);
-		GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
-		GtkWidget *titleLabel = gtk_label_new (title);
-		GtkWidget *contentLabel = gtk_label_new (contentLabelText);
-		//GdkColor color;
-		//gtk_widget_ensure_style (contentLabel);
-		//gtk_style_lookup_color (contentLabel->style, "SecondaryTextColor", &color);
-		//g_warning ("%s", gdk_color_to_string (&color));
-		//gtk_widget_modify_text (contentLabel, GTK_STATE_ACTIVE, &color);
-		
-		gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<small>", contentLabelText, "</small>", NULL));
-		gtk_container_add (GTK_CONTAINER (event), vbox);
-		gtk_container_add (GTK_CONTAINER (vbox), titleLabel);
-		gtk_container_add (GTK_CONTAINER (vbox), contentLabel);
-		gtk_container_add (GTK_CONTAINER (self->priv->contents), event);
-		
-		g_signal_connect (event, "button-release-event", G_CALLBACK (countdown_home_widget_edit_event), self);
-		
-		gchar *name=g_strdup_printf("%d",self->priv->offset + count++);
-		
-		gtk_widget_set_name (event, name);
-		
-		g_free (contentLabelText);
-		g_free (title);
-		g_free (date);
-		g_free (time);
-		g_free (name);
-		g_free (tail);
-		g_strfreev (content);
-		
-		exists = gtk_tree_model_iter_next (GTK_TREE_MODEL (self->priv->entries), &iter);
-		if (exists) {
-			if (count >= 3) {
-				exists = FALSE;
+			content[index] = g_strconcat (tail, NULL);
+			
+			contentLabelText = g_strjoinv (NULL, content);
+			GtkWidget *event = gtk_event_box_new ();
+			gtk_event_box_set_visible_window (GTK_EVENT_BOX (event), FALSE);
+			gtk_container_set_border_width (GTK_CONTAINER (event), 5);
+			GtkWidget *vbox = gtk_vbox_new (TRUE, 0);
+			GtkWidget *titleLabel = gtk_label_new (title);
+			gtk_label_set_ellipsize (GTK_LABEL (titleLabel), PANGO_ELLIPSIZE_END);
+			GtkWidget *contentLabel = gtk_label_new (contentLabelText);
+			GdkColor color;
+			gtk_style_lookup_color (gtk_rc_get_style(contentLabel), "SecondaryTextColor", &color);
+			gtk_label_set_markup (GTK_LABEL (contentLabel), g_strconcat ("<span size=\"smaller\" color=\"",gdk_color_to_string (&color),"\">", contentLabelText, "</span>", NULL));
+			gtk_label_set_ellipsize (GTK_LABEL (contentLabel), PANGO_ELLIPSIZE_END);
+
+			gtk_container_add (GTK_CONTAINER (event), vbox);
+			gtk_container_add (GTK_CONTAINER (vbox), titleLabel);
+			gtk_container_add (GTK_CONTAINER (vbox), contentLabel);
+			gtk_container_add (GTK_CONTAINER (self->priv->contents), event);
+			
+			g_signal_connect (event, "button-release-event", G_CALLBACK (countdown_home_widget_edit_event), self);
+			
+			gchar *name=g_strdup_printf("%d",self->priv->offset + count++);
+			
+			gtk_widget_set_name (event, name);
+			
+			g_free (contentLabelText);
+			g_free (title);
+			g_free (date);
+			g_free (time);
+			g_free (name);
+			g_free (tail);
+			g_strfreev (content);
+			
+			exists = gtk_tree_model_iter_next (GTK_TREE_MODEL (self->priv->entries), &iter);
+			if (exists) {
+				if (count >= 3) {
+					exists = FALSE;
+				}
 			}
 		}
+	} else {
+		GtkWidget *label = gtk_label_new ("You currently have no countdown events set up.  Press the '+' button below to start adding events!");
+		gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+		gtk_widget_set_size_request (label, 352, -1);
+		gtk_container_add (GTK_CONTAINER (self->priv->contents), label);
 	}
 
 	if (totalRows > 3) {
